""" Common filenames and locations for topographic data, meshes and outputs.
    This file defines the parameters of the scenario you wish to run.
"""

from anuga.geometry.polygon import read_polygon, plot_polygons, \
                                    polygon_area, is_inside_polygon

#------------------------------------------------------------------------------
# Define scenario as either slide or fixed_wave. Choose one.
#------------------------------------------------------------------------------
#scenario = 'fixed_wave' # Huge wave applied at the boundary
scenario = 'slide'       # Slide wave form applied inside the domain

#------------------------------------------------------------------------------
# Filenames
#------------------------------------------------------------------------------
demname = 'cairns'
meshname = demname + '.msh'

# Filename for locations where timeseries are to be produced
gauge_filename = 'gauges.csv'

#------------------------------------------------------------------------------
# Domain definitions
#------------------------------------------------------------------------------
# bounding polygon for study area
bounding_polygon = read_polygon('extent.csv')

A = polygon_area(bounding_polygon) / 1000000.0
print 'Area of bounding polygon = %.2f km^2' % A

#------------------------------------------------------------------------------
# Interior region definitions
#------------------------------------------------------------------------------
# Read interior polygons
poly_cairns = read_polygon('cairns.csv')
poly_island0 = read_polygon('islands.csv')
poly_island1 = read_polygon('islands1.csv')
poly_island2 = read_polygon('islands2.csv')
poly_island3 = read_polygon('islands3.csv')
poly_shallow = read_polygon('shallow.csv')

# Optionally plot points making up these polygons
#plot_polygons([bounding_polygon, poly_cairns, poly_island0, poly_island1,
#               poly_island2, poly_island3, poly_shallow],
#               style='boundingpoly', verbose=False)

# Define resolutions (max area per triangle) for each polygon
# Make these numbers larger to reduce the number of triangles in the model,
# and hence speed up the simulation
default_res = 10000000    # Background resolution
islands_res = 100000
cairns_res = 100000
shallow_res = 500000

# Define list of interior regions with associated resolutions
interior_regions = [[poly_cairns,  cairns_res],
                    [poly_island0, islands_res],
                    [poly_island1, islands_res],
                    [poly_island2, islands_res],
                    [poly_island3, islands_res],
                    [poly_shallow, shallow_res]]

#------------------------------------------------------------------------------
# Data for exporting ascii grid
#------------------------------------------------------------------------------
eastingmin = 363000
eastingmax = 418000
northingmin = 8026600
northingmax = 8145700

#------------------------------------------------------------------------------
# Data for landslide
#------------------------------------------------------------------------------
slide_origin = [451871, 8128376]   # Assume to be on continental shelf
slide_depth = 500.
